@@ -42,7 +42,7 @@ test_that("Checks for y",{
   expect_is(explainer_ranger_6, "explainer")
   expect_is(explainer_ranger_7, "explainer")
   expect_is(explainer_ranger_7$y, "numeric")
-  
+
   expect_output(explain(model_multiclassif_ranger_prob, data = HR, y = as.numeric(HR$status)),
                 "Model info detected multiclass task but 'y' is a numeric")
   expect_output(explain(model_regr_ranger, data = apartments, y = apartments$district),
@@ -92,6 +92,16 @@ test_that("predict and residual functions", {
 
 })
 
+test_that("Positive class works", {
+  explainer_ranger_20 <- explain(model_classif_ranger, data = titanic_imputed[,-8], y = titanic_imputed$survived, verbose = FALSE)
+  explainer_ranger_21 <- explain(model_classif_ranger, data = titanic_imputed[,-8], y = titanic_imputed$survived, verbose = FALSE, predict_function_target_column = 1)
+
+  expect_is(explainer_ranger_20$y_hat, "numeric")
+  expect_is(explainer_ranger_21$y_hat, "numeric")
+  expect_false(all(explainer_ranger_20$y_hat == explainer_ranger_21$y_hat))
+
+})
+
 test_that("Checks tests", {
   expect_error(explain(model_classif_ranger, y = titanic_imputed$survived, verbose = FALSE), NA)
   expect_error(explain(model_classif_ranger, weights = rep(1, times=nrow(titanic_imputed)), verbose = FALSE), NA)
